package com.sun.xml.internal.ws.server;

import com.sun.xml.internal.ws.api.server.SDDocument;
import java.util.Iterator;
import java.util.HashMap;
import java.util.ArrayList;
import com.sun.xml.internal.ws.api.server.SDDocumentFilter;
import com.sun.istack.internal.NotNull;
import java.util.Map;
import java.util.List;
import com.sun.xml.internal.ws.wsdl.SDDocumentResolver;
import com.sun.xml.internal.ws.api.server.ServiceDefinition;

public final class ServiceDefinitionImpl implements ServiceDefinition, SDDocumentResolver
{
    private final List<SDDocumentImpl> docs;
    private final Map<String, SDDocumentImpl> bySystemId;
    @NotNull
    private final SDDocumentImpl primaryWsdl;
    WSEndpointImpl<?> owner;
    final List<SDDocumentFilter> filters;
    
    public ServiceDefinitionImpl(List<SDDocumentImpl> docs, @NotNull SDDocumentImpl primaryWsdl) {
        this.filters = new ArrayList();
        assert !(!docs.contains(primaryWsdl));
        this.docs = docs;
        this.primaryWsdl = primaryWsdl;
        this.bySystemId = new HashMap(docs.size());
        for (SDDocumentImpl doc : docs) {
            this.bySystemId.put(doc.getURL().toExternalForm(), doc);
            doc.setFilters(this.filters);
            doc.setResolver(this);
        }
        return;
    }
    
    void setOwner(WSEndpointImpl<?> owner) {
        assert owner != null && this.owner == null;
        this.owner = owner;
        return;
    }
    
    @NotNull
    public SDDocument getPrimary() {
        return this.primaryWsdl;
    }
    
    public void addFilter(SDDocumentFilter filter) {
        this.filters.add(filter);
    }
    
    public Iterator<SDDocument> iterator() {
        return this.docs.iterator();
    }
    
    public SDDocument resolve(String systemId) {
        return (SDDocument)this.bySystemId.get(systemId);
    }
}
